@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	consolev1 "github.com/openshift/api/console/v1"
+	routev1 "github.com/openshift/api/route/v1"
 	apiextensionsv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
 	"os"
 
@@ -46,17 +47,25 @@ var (
 	}
 )
 
-func initReconciler(client client.Client) *ReconcileHyperConverged {
+func initReconciler(client client.Client, old *ReconcileHyperConverged) *ReconcileHyperConverged {
 	s := commonTestUtils.GetScheme()
 	eventEmitter := commonTestUtils.NewEventEmitterMock()
 	operandHandler := operands.NewOperandHandler(client, s, true, eventEmitter)
+	upgradeMode := false
+	firstLoop := true
+	if old != nil {
+		upgradeMode = old.upgradeMode
+		firstLoop = old.firstLoop
+	}
 	// Create a ReconcileHyperConverged object with the scheme and fake client
 	return &ReconcileHyperConverged{
 		client:         client,
 		scheme:         s,
 		operandHandler: operandHandler,
 		eventEmitter:   eventEmitter,
-		firstLoop:      true,
+		firstLoop:      firstLoop,
+		ownVersion:     version.Version,
+		upgradeMode:    upgradeMode,
 	}
 }
 
@@ -76,6 +85,8 @@ type BasicExpected struct {
 	serviceMonitor       *monitoringv1.ServiceMonitor
 	promRule             *monitoringv1.PrometheusRule
 	cliDownload          *consolev1.ConsoleCLIDownload
+	cliDownloadsRoute    *routev1.Route
+	cliDownloadsService  *corev1.Service
 	hcoCRD               *apiextensionsv1.CustomResourceDefinition
 }
 
@@ -96,6 +107,8 @@ func (be BasicExpected) toArray() []runtime.Object {
 		be.serviceMonitor,
 		be.promRule,
 		be.cliDownload,
+		be.cliDownloadsRoute,
+		be.cliDownloadsService,
 		be.hcoCRD,
 	}
 }
@@ -112,13 +125,14 @@ func getBasicDeployment() *BasicExpected {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      name,
 			Namespace: namespace,
+			Labels:    map[string]string{hcoutil.AppLabel: name},
 		},
 		Spec: hcov1beta1.HyperConvergedSpec{},
 		Status: hcov1beta1.HyperConvergedStatus{
-			Conditions: []conditionsv1.Condition{
+			Conditions: []metav1.Condition{
 				{
 					Type:    hcov1beta1.ConditionReconcileComplete,
-					Status:  corev1.ConditionTrue,
+					Status:  metav1.ConditionTrue,
 					Reason:  common.ReconcileCompleted,
 					Message: common.ReconcileCompletedMessage,
 				},
@@ -138,11 +152,11 @@ func getBasicDeployment() *BasicExpected {
 	expectedKVStorageConfig := operands.NewKubeVirtStorageConfigForCR(hco, namespace)
 	expectedKVStorageConfig.ObjectMeta.SelfLink = fmt.Sprintf("/apis/v1/namespaces/%s/configmaps/%s", expectedKVStorageConfig.Namespace, expectedKVStorageConfig.Name)
 	res.kvStorageConfig = expectedKVStorageConfig
-	expectedKVStorageRole := operands.NewKubeVirtStorageRoleForCR(hco, namespace, commonTestUtils.GetScheme())
+	expectedKVStorageRole := operands.NewConfigReaderRoleForCR(hco, namespace)
 	expectedKVStorageRole.ObjectMeta.SelfLink = fmt.Sprintf("/apis/v1/namespaces/%s/roles/%s", expectedKVStorageConfig.Namespace, expectedKVStorageConfig.Name)
 	res.kvStorageRole = expectedKVStorageRole
 
-	expectedKVStorageRoleBinding := operands.NewKubeVirtStorageRoleBindingForCR(hco, namespace, commonTestUtils.GetScheme())
+	expectedKVStorageRoleBinding := operands.NewConfigReaderRoleBindingForCR(hco, namespace)
 	expectedKVStorageRoleBinding.ObjectMeta.SelfLink = fmt.Sprintf("/apis/v1/namespaces/%s/rolebindings/%s", expectedKVStorageConfig.Namespace, expectedKVStorageConfig.Name)
 	res.kvStorageRoleBinding = expectedKVStorageRoleBinding
 
@@ -197,6 +211,14 @@ func getBasicDeployment() *BasicExpected {
 	expectedCliDownload.SelfLink = fmt.Sprintf("/apis/console.openshift.io/v1/consoleclidownloads/%s", expectedCliDownload.Name)
 	res.cliDownload = expectedCliDownload
 
+	expectedCliDownloadsRoute := operands.NewCliDownloadsRoute(hco)
+	expectedCliDownloadsRoute.SelfLink = fmt.Sprintf("/apis/route.openshift.io/v1/namespaces/%s/routes/%s", expectedCliDownloadsRoute.Namespace, expectedCliDownloadsRoute.Name)
+	res.cliDownloadsRoute = expectedCliDownloadsRoute
+
+	expectedCliDownloadsService := operands.NewCliDownloadsService(hco)
+	expectedCliDownloadsService.SelfLink = fmt.Sprintf("/apis/v1/namespaces/%s/services/%s", expectedCliDownloadsService.Namespace, expectedCliDownloadsService.Name)
+	res.cliDownloadsService = expectedCliDownloadsService
+
 	hcoCrd := &apiextensionsv1.CustomResourceDefinition{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: "hyperconvergeds.hco.kubevirt.io",
@@ -208,9 +230,10 @@ func getBasicDeployment() *BasicExpected {
 }
 
 // returns the HCO after reconcile, and the returned requeue
-func doReconcile(cl client.Client, hco *hcov1beta1.HyperConverged) (*hcov1beta1.HyperConverged, bool) {
-	r := initReconciler(cl)
+func doReconcile(cl client.Client, hco *hcov1beta1.HyperConverged, old *ReconcileHyperConverged) (*hcov1beta1.HyperConverged, *ReconcileHyperConverged, bool) {
+	r := initReconciler(cl, old)
 
+	r.firstLoop = false
 	r.ownVersion = os.Getenv(hcoutil.HcoKvIoVersionName)
 	if r.ownVersion == "" {
 		r.ownVersion = version.Version
@@ -226,7 +249,7 @@ func doReconcile(cl client.Client, hco *hcov1beta1.HyperConverged) (*hcov1beta1.
 			foundResource),
 	).To(BeNil())
 
-	return foundResource, res.Requeue
+	return foundResource, r, res.Requeue
 }
 
 func getGenericCompletedConditions() []conditionsv1.Condition {
@@ -267,10 +290,10 @@ func checkHcoReady() bool {
 	return hcoutil.IsReady()
 }
 
-func checkAvailability(hco *hcov1beta1.HyperConverged, expected corev1.ConditionStatus) {
+func checkAvailability(hco *hcov1beta1.HyperConverged, expected metav1.ConditionStatus) {
 	found := false
 	for _, cond := range hco.Status.Conditions {
-		if cond.Type == conditionsv1.ConditionType(kubevirtv1.KubeVirtConditionAvailable) {
+		if cond.Type == hcov1beta1.ConditionAvailable {
 			found = true
 			ExpectWithOffset(1, cond.Status).To(Equal(expected))
 			break
