@@ -11,6 +11,7 @@ import (
 	. "github.com/onsi/gomega"
 	consolev1 "github.com/openshift/api/console/v1"
 	corev1 "k8s.io/api/core/v1"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	kubevirtv1 "kubevirt.io/client-go/api/v1"
 	cdiv1beta1 "kubevirt.io/containerized-data-importer/pkg/apis/core/v1beta1"
@@ -26,10 +27,10 @@ var _ = Describe("Test operandHandler", func() {
 		_ = os.Setenv("CONVERSION_CONTAINER", "just-a-value:version")
 		_ = os.Setenv("VMWARE_CONTAINER", "just-a-value:version")
 		_ = os.Setenv("VIRTIOWIN_CONTAINER", "just-a-value:version")
+		_ = os.Setenv(quickStartManifestLocationVarName, testFileLocation+"/quickstarts")
+		_ = os.Setenv(dashboardManifestLocationVarName, testFileLocation+"/dashboards")
 
 		It("should create all objects are created", func() {
-			err := os.Setenv(manifestLocationVarName, testFileLocation)
-			Expect(err).ToNot(HaveOccurred())
 			hco := commonTestUtils.NewHco()
 			cli := commonTestUtils.InitClient([]runtime.Object{qsCrd, hco})
 
@@ -40,14 +41,9 @@ var _ = Describe("Test operandHandler", func() {
 
 			req := commonTestUtils.NewReq(hco)
 
-			err = handler.Ensure(req)
+			err := handler.Ensure(req)
 			Expect(err).ToNot(HaveOccurred())
 			expectedEvents := []commonTestUtils.MockEvent{
-				{
-					EventType: corev1.EventTypeNormal,
-					Reason:    "Created",
-					Msg:       "Created ConfigMap kubevirt-config",
-				},
 				{
 					EventType: corev1.EventTypeNormal,
 					Reason:    "Created",
@@ -108,8 +104,13 @@ var _ = Describe("Test operandHandler", func() {
 					Reason:    "Created",
 					Msg:       "Created ConsoleQuickStart test-quick-start",
 				},
+				{
+					EventType: corev1.EventTypeNormal,
+					Reason:    "Created",
+					Msg:       "Created ConfigMap grafana-dashboard-kubevirt-top-consumers",
+				},
 			}
-			Expect(eventEmitter.CheckEvents(expectedEvents))
+			Expect(eventEmitter.CheckEvents(expectedEvents)).To(BeTrue())
 
 			By("make sure the KV object created", func() {
 				// Read back KV
@@ -160,11 +161,18 @@ var _ = Describe("Test operandHandler", func() {
 				Expect(qsList.Items).To(HaveLen(1))
 				Expect(qsList.Items[0].Name).Should(Equal("test-quick-start"))
 			})
+
+			By("make sure the Dashboard confimap created", func() {
+				cmList := corev1.ConfigMapList{}
+				err := cli.List(req.Ctx, &cmList, &client.ListOptions{Namespace: "openshift-config-managed"})
+				Expect(err).ToNot(HaveOccurred())
+				Expect(cmList).ToNot(BeNil())
+				Expect(cmList.Items).To(HaveLen(1))
+				Expect(cmList.Items[0].Name).Should(Equal("grafana-dashboard-kubevirt-top-consumers"))
+			})
 		})
 
 		It("should handle errors on ensure loop", func() {
-			err := os.Setenv(manifestLocationVarName, testFileLocation)
-			Expect(err).ToNot(HaveOccurred())
 			hco := commonTestUtils.NewHco()
 			cli := commonTestUtils.InitClient([]runtime.Object{qsCrd, hco})
 
@@ -185,14 +193,14 @@ var _ = Describe("Test operandHandler", func() {
 				return nil
 			})
 
-			err = handler.Ensure(req)
+			err := handler.Ensure(req)
 			Expect(err).To(HaveOccurred())
 			Expect(err).Should(Equal(fakeError))
 
 			Expect(req.ComponentUpgradeInProgress).To(BeFalse())
 			cond := req.Conditions[hcov1beta1.ConditionReconcileComplete]
 			Expect(cond).ToNot(BeNil())
-			Expect(cond.Status).Should(Equal(corev1.ConditionFalse))
+			Expect(cond.Status).Should(Equal(metav1.ConditionFalse))
 			Expect(cond.Reason).Should(Equal(reconcileFailed))
 			Expect(cond.Message).Should(Equal(fmt.Sprintf("Error while reconciling: %v", fakeError)))
 
@@ -207,8 +215,6 @@ var _ = Describe("Test operandHandler", func() {
 		})
 
 		It("make sure the all objects are deleted", func() {
-			err := os.Setenv(manifestLocationVarName, testFileLocation)
-			Expect(err).ToNot(HaveOccurred())
 			hco := commonTestUtils.NewHco()
 			cli := commonTestUtils.InitClient([]runtime.Object{qsCrd, hco})
 
@@ -217,7 +223,7 @@ var _ = Describe("Test operandHandler", func() {
 			handler.FirstUseInitiation(commonTestUtils.GetScheme(), true, hco)
 
 			req := commonTestUtils.NewReq(hco)
-			err = handler.Ensure(req)
+			err := handler.Ensure(req)
 			Expect(err).ToNot(HaveOccurred())
 
 			eventEmitter.Reset()
@@ -260,6 +266,11 @@ var _ = Describe("Test operandHandler", func() {
 					Reason:    "Killing",
 					Msg:       "Removed KubeVirt kubevirt-kubevirt-hyperconverged",
 				},
+				{
+					EventType: corev1.EventTypeNormal,
+					Reason:    "Killing",
+					Msg:       "Removed ConfigMap grafana-dashboard-kubevirt-top-consumers",
+				},
 			}
 			Expect(eventEmitter.CheckEvents(expectedEvents)).To(BeTrue())
 
@@ -310,8 +321,6 @@ var _ = Describe("Test operandHandler", func() {
 		})
 
 		It("delete KV error handling", func() {
-			err := os.Setenv(manifestLocationVarName, testFileLocation)
-			Expect(err).ToNot(HaveOccurred())
 			hco := commonTestUtils.NewHco()
 			cli := commonTestUtils.InitClient([]runtime.Object{qsCrd, hco})
 
@@ -321,7 +330,7 @@ var _ = Describe("Test operandHandler", func() {
 			handler.FirstUseInitiation(commonTestUtils.GetScheme(), true, hco)
 
 			req := commonTestUtils.NewReq(hco)
-			err = handler.Ensure(req)
+			err := handler.Ensure(req)
 			Expect(err).ToNot(HaveOccurred())
 
 			fakeError := fmt.Errorf("fake KV deletion error")
@@ -362,8 +371,6 @@ var _ = Describe("Test operandHandler", func() {
 		})
 
 		It("delete CDI error handling", func() {
-			err := os.Setenv(manifestLocationVarName, testFileLocation)
-			Expect(err).ToNot(HaveOccurred())
 			hco := commonTestUtils.NewHco()
 			cli := commonTestUtils.InitClient([]runtime.Object{qsCrd, hco})
 
@@ -372,7 +379,7 @@ var _ = Describe("Test operandHandler", func() {
 			handler.FirstUseInitiation(commonTestUtils.GetScheme(), true, hco)
 
 			req := commonTestUtils.NewReq(hco)
-			err = handler.Ensure(req)
+			err := handler.Ensure(req)
 			Expect(err).ToNot(HaveOccurred())
 
 			fakeError := fmt.Errorf("fake CDI deletion error")
@@ -414,8 +421,6 @@ var _ = Describe("Test operandHandler", func() {
 		})
 
 		It("default delete error handling", func() {
-			err := os.Setenv(manifestLocationVarName, testFileLocation)
-			Expect(err).ToNot(HaveOccurred())
 			hco := commonTestUtils.NewHco()
 			cli := commonTestUtils.InitClient([]runtime.Object{qsCrd, hco})
 
@@ -426,7 +431,7 @@ var _ = Describe("Test operandHandler", func() {
 			handler.FirstUseInitiation(commonTestUtils.GetScheme(), true, hco)
 
 			req := commonTestUtils.NewReq(hco)
-			err = handler.Ensure(req)
+			err := handler.Ensure(req)
 			Expect(err).ToNot(HaveOccurred())
 
 			cli.InitiateDeleteErrors(func(obj client.Object) error {
@@ -467,8 +472,6 @@ var _ = Describe("Test operandHandler", func() {
 		})
 
 		It("delete timeout error handling", func() {
-			err := os.Setenv(manifestLocationVarName, testFileLocation)
-			Expect(err).ToNot(HaveOccurred())
 			hco := commonTestUtils.NewHco()
 			cli := commonTestUtils.InitClient([]runtime.Object{qsCrd, hco})
 
@@ -478,7 +481,7 @@ var _ = Describe("Test operandHandler", func() {
 			handler.FirstUseInitiation(commonTestUtils.GetScheme(), true, hco)
 
 			req := commonTestUtils.NewReq(hco)
-			err = handler.Ensure(req)
+			err := handler.Ensure(req)
 			Expect(err).ToNot(HaveOccurred())
 
 			cli.InitiateDeleteErrors(func(obj client.Object) error {
